Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
lmcat\__init__.py | (no class) | 2 | 0 | 0 | 100%
lmcat\__main__.py | (no class) | 3 | 3 | 0 | 0%
lmcat\lmcat.py | LMCatConfig | 28 | 22 | 0 | 21%
lmcat\lmcat.py | IgnoreHandler | 14 | 0 | 0 | 100%
lmcat\lmcat.py | (no class) | 103 | 43 | 0 | 58%
tests\test_lmcat.py | (no class) | 192 | 11 | 0 | 94%
Total |  | 342 | 79 | 0 | 77%

No items found using the specified filter.